/// <reference types="./types" />
export declare const renderDomByMd: (vditor: IVditor, md: string, options?: {
    enableAddUndoStack: boolean;
    enableHint: boolean;
    enableInput: boolean;
}) => void;
