export declare const isSafari: () => boolean;
export declare const isFirefox: () => boolean;
export declare const accessLocalStorage: () => boolean;
export declare const getEventName: () => "click" | "touchstart";
export declare const isCtrl: (event: KeyboardEvent) => boolean;
export declare const updateHotkeyTip: (hotkey: string) => string;
export declare const isChrome: () => boolean;
