/// <reference types="./types" />
export declare const download: (vditor: IVditor, content: string, filename: string) => void;
export declare const exportMarkdown: (vditor: IVditor) => void;
export declare const exportPDF: (vditor: IVditor) => void;
export declare const exportHTML: (vditor: IVditor) => void;
