/// <reference types="./types" />
export declare const highlightToolbarWYSIWYG: (vditor: IVditor) => void;
export declare const genLinkRefPopover: (vditor: IVditor, linkRefElement: HTMLElement) => void;
export declare const genAPopover: (vditor: IVditor, aElement: HTMLElement) => void;
export declare const genImagePopover: (event: Event, vditor: IVditor) => void;
